function text_encoded = encoder(text, f_s, f, T_b, E_b, l_expand)
% text_encoded = encoder(text, f_s, f, T_b, E_b)
%
% Arguments:
%   text: a char array with the text for encoding
%   f_s:  frequency of sampling
%   f:    array with length 2 that keeps the frequences of the sines
%   T_b:  Period of each bit's transmition
%   E_b:  Energy of signal for each bit

% period of sampling
T_s = 1 / f_s;

% convert the text - charachters to ascii decimal code
dec_symbol_array = text - 0;

% convert each decimal to a row of 8-bit's binary numbers
bin_symbol_matrix = dec2bin(dec_symbol_array, 8);

% concatenate the rows to a single column
bin_symbol_array = bin2dec(reshape(bin_symbol_matrix, [], 1));

% the total number of samples that must be used for the signal to transmit
% a bit
num_samples_per_bit = ceil(T_b / T_s);

% pad the bit-ascii text with null characters in order to add it then with
% the voice signal (http://www.asciitable.com/)
bin_symbol_array = padarray(bin_symbol_array, [l_expand], 'post');

% the length of the the text represented with bits in ascii code
M = length(bin_symbol_array);

% the total number of samples that must be used for the signal to
% transmit the text
num_samples = M * num_samples_per_bit;

% initialize the text_encoded array with zeros 
text_encoded = zeros(num_samples, 1);

for n = 1: num_samples
     for m = 0: M-1 
            text_encoded(n, 1) = text_encoded(n,1) + phi_l(bin_symbol_array(floor((n - 1)/num_samples_per_bit) + 1, 1), n * T_s - m * T_b, f, T_b, E_b);
     end
end

% Debugging
% plot that represents the digital signal of text (encoded)
plot([1:num_samples] , text_encoded);
% title of the plot
title('Text Encoding');
% title of the x axis
xlabel('time');
% title of the y axis
ylabel('signal of text');

end