function [ y_n ] = transmitter( voice, text, f_s, f, T_b, E_b)
% The function that calculates the y_n signal that is the addition of both
% the (sampled) voice signal and the encoded text signal
% [ y_n ] = transmitter( voice, text, f_s, f, T_b, E_b)
%
% Arguments:
%   voice: the signal that is already sampled and must be added with the
%          signal of the text
%   text:  a char array with the text for encoding
%   f_s:   frequency of sampling
%   f:     array with length 2 that keeps the frequences of the sines
%   T_b:   Period of each bit's transmition
%   E_b:   Energy of signal for each bit

% period of sampling
T_s = 1 / f_s;

% the length of the text (actually the total number of samples needed)
text_length = num_samples(text, T_b, T_s);

% the length of the signal that we want to transmit with a text
voice_length = length(voice);

% the difference between the length of the text signal and the voice signal
diff = abs(text_length - voice_length);

% pad the smaller signal with the method of post null ascii  charachters
% for the text or with zero for the voice
if (text_length > voice_length)
    % produce the signal of the text without padding anything to it
    text = encoder(text, f_s, f, T_b, E_b, 0);
    voice = padarray(voice, [diff], 'post');
else
    % produce the signal of the text after padding it with the missing null
    % ascii charachters
    text = encoder(text, f_s, f, T_b, E_b, diff);
end

% the digital signal to be transmitted (it is the addition of both
% the (sampled) voice signal and the encoded text signal) 
y_n = voice + text;

end

